@@ -5,6 +5,7 @@
 #' @param D matrix of vertices of a tropical polytope; rows are the vertices
 #' @param c string; color to render the polytope.
 #' @param cc string; color to render the vertices.
+#' @param plt logical; initiate new plot visualization or not.
 #' @return 2-D or 3-D rendering of a tropical polytope.
 #' @author Ruriko Yoshida \email{ryoshida@@nps.edu}
 #' @name draw.tpolytope
@@ -13,12 +14,12 @@
 #'D <-matrix(c(0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1),4,4,TRUE)
 #'c<-'blue'
 #'cc<-'red'
-#'draw.tpolytope.3d(D,c,cc)
+#'draw.tpolytope.3d(D,c,cc,plt=TRUE)
 #'
 #'D <- matrix(c(0,-2,2,0,-2,5,0,2,1,0,1,-1),4,3,TRUE)
 #'c <- 'blue'
 #'cc <- 'red'
-#'draw.tpolytope.2d(D,c,cc)
+#'draw.tpolytope.2d(D,c,cc,plt=TRUE)
 #'
 #'
 
@@ -26,7 +27,7 @@
 ### Only for e = 4.
 #' @rdname draw.tpolytope
 #' @export
-draw.tpolytope.3d <- function(D,c,cc){
+draw.tpolytope.3d <- function(D,c,cc,plt=TRUE){
   d <- dim(D)
   D1 <- D
   for(i in 1:(d[1] - 1)){
@@ -35,15 +36,17 @@ draw.tpolytope.3d <- function(D,c,cc){
       D1 <- rbind(D1, M)
     }
   }
-  pre.draw.tpolytope.3d(D1, d[1],c,cc)
+  pre.draw.tpolytope.3d(D1, d[1],c,cc,plt)
 
 }
 
 #' @rdname draw.tpolytope
 #' @export
-draw.tpolytope.2d<-function(D,c,cc){
+draw.tpolytope.2d<-function(D,c,cc,plt=TRUE){
   coms<-combn(c(1:nrow(D)),2)
-  plot(D[,2],D[,3],asp=1,pch=19,col='white',xlab='x2',ylab='x3')
+  if(plt==TRUE){
+    plot(D[,2],D[,3],asp=1,pch=19,col='white',xlab='x2',ylab='x3')
+  }
   for (i in 1:ncol(coms)){
     a<-coms[1,i]
     b<-coms[2,i]
@@ -55,7 +58,7 @@ draw.tpolytope.2d<-function(D,c,cc){
   points(D[,2],D[,3],pch=19,col=cc)
 }
 
-pre.draw.tpolytope.3d <- function(D, v,c,cc){
+pre.draw.tpolytope.3d <- function(D, v,c,cc,plt=TRUE){
   d <- dim(D)
   seg <- matrix(rep(0, 3*choose(d[1], 2)*(2*3)), 3*choose(d[1], 2), 6)
   counter <- 1
@@ -75,6 +78,9 @@ pre.draw.tpolytope.3d <- function(D, v,c,cc){
              z=as.vector(t(seg[1:(counter-1), c(3,6)])), col = c, lwd = .2,tcl=-.9)
   for(i in 1:v)
     spheres3d(D[i, 2:4], radius = 0.05, color = cc)
-  axes3d()
-  title3d(xlab="X",ylab="Y",zlab="Z")
+  if(plt==TRUE){
+    axes3d()
+    title3d(xlab="X",ylab="Y",zlab="Z")
+  }
+
 }
